% zip2grade.m Zips source code & documentation files for grading.
%
% This script zips together source code (.m), manually created 
% documentation (.docx) and automatically generated (by m2html)
% documenation files. It prompts the user for the assignment name (folder).
% It reads the user name and documentation folder name from the
% z2gconfig.txt in the Matlab current folder. The Matlab current folder 
% should be one directly level above the assignment and documentation 
% folders.
%
% For example, if the current folder is d:\ge4200 and it contains the
% assignment folder Prob3 and the document folder matDocs and the user name
% is Tritt, this script should be placed in d:\ge4200 which should also be
% set as the current folder. In this case z2gconfig.txt should contain:
%
% zip2grade.m configuration file: User name and Matlab document folder.
% Tritt
% matDocs
%
% And the user should enter Prob3 when prompted for the assignment name.
% In this case, the script would zip the contents of the two folders into a
% file called TrittProb3.
%
% This script creates a temporary folder where it copies the documentation
% and source code files before zipping them. It places the zip file in the
% current folder and removes the temporary folder when it is done.
%
% An error message is displayed if the temporary folder already exists when
% the program is run. In this case, the user should confirm the folder
% doesn't contain anything important and then delete it before running this
% script again.
%
% It provides other reasonable messages and options if other things go 
% wrong.
%
% Created by Dr. C. S. Tritt
% Last revised 1/2/12 (v. 1.0)

% Start clean

clc; clear; close all;

% Check for configuration file existance & read it.

if ~exist('z2gconfig.txt', 'file')
   errordlg('No z2gconfig.txt file found. Aborting.');
   return;
end

hConfigFile = fopen('z2gconfig.txt', 'r');
header = fgetl(hConfigFile); % Read but not used.
userName = fgetl(hConfigFile); % User name.
docFolder =  fgetl(hConfigFile); % Matlab document folder.

if ~exist(docFolder, 'file')
   errordlg([docFolder ' document folder not found. Aborting.']);
   return;
end

% Get the assignment (project) name and confirm it exists.

csProjName = inputdlg('Enter assignment (source code folder) name:');
sProjName = csProjName{1}; % Extract project name string from cell string.

if ~exist(sProjName, 'file')
   errordlg([sProjName ' assignment folder not found. Aborting.']);
   return;
end

% Build zip name and check for zip file existance.

zipName = [userName sProjName];
zipFile = [zipName '.zip'];
if exist(zipFile, 'file')
   sPrompt = [zipFile ' exists. Your options are...'];
   csList = {'Delete file & continue.', 'Abort script.'};
   selection = listdlg('PromptString', sPrompt, 'ListString', csList, ...
      'SelectionMode', 'single', 'Name', 'zip2grade', 'ListSize', ...
      [280, 100]);
   if selection == 1
      delete(zipFile)
   else
      return % Abort on command or cancel.
   end
end

% Check for temporary folder existance before overwriting it. Try to
% create it and abort on failure. Note that temp folder is created after
% most other failure modes have been considered to avoid creating it 
% unnecessarily.

tempName = 'docTemp'; % Edit this line to change temporary folder name.

if exist(tempName, 'file')
   sPrompt = [tempName ' folder exists. Your options are...'];
   csList = {'Remove folder & continue.', 'Abort script.'};
   selection = listdlg('PromptString', sPrompt, 'ListString', csList, ...
      'SelectionMode', 'single', 'Name', 'zip2grade', 'ListSize', ...
      [300, 100]);
   if selection == 1
      rmdir(tempName, 's') % Delete contents and remove folder.
   else
      return % Abort on command or cancel.
   end
end

status = mkdir(tempName); % Status is true for success.
if ~status
   errordlg('Failure creating temporary folder. Aborting.');
   return;
end

% Copy project and document files (with subfolders) to temporary folder.

copyfile(sProjName, tempName); % Source code & and manual documentation.
copyfile([docFolder '\' sProjName], tempName); % m2html documentation.

% Zip them to userNameproject.zip in current folder.

zip(zipName, [tempName '\*.*']);

status = rmdir(tempName, 's'); % Delete subfolders & files, remove folder.
if ~status
   errordlg('Failure removing temporary folder.');
end

% Everything worked.

msgbox([zipFile ' sucessfully created.'], 'zip2grade');